@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
  *
@@ -29,8 +30,10 @@ void		gs_plugin_packagekit_resolve_packages_app	(GsPlugin *plugin,
 void		gs_plugin_packagekit_set_metadata_from_package	(GsPlugin *plugin,
 								 GsApp *app,
 								 PkPackage *package);
+GHashTable *	gs_plugin_packagekit_details_array_to_hash	(GPtrArray *array);
 void		gs_plugin_packagekit_refine_details_app		(GsPlugin *plugin,
-								 GPtrArray *array,
+								 GHashTable *details_collection,
+								 GHashTable *prepared_updates,
 								 GsApp *app);
 void		gs_plugin_packagekit_set_packaging_format	(GsPlugin *plugin,
 								 GsApp *app);
