@@ -22,7 +22,7 @@
 
 struct _GsReposDialog
 {
-	HdyWindow	 parent_instance;
+	AdwWindow	 parent_instance;
 	GSettings	*settings;
 	GsFedoraThirdParty *third_party;
 	gboolean	 third_party_enabled;
@@ -37,15 +37,15 @@ struct _GsReposDialog
 	GtkWidget	*stack;
 };
 
-G_DEFINE_TYPE (GsReposDialog, gs_repos_dialog, HDY_TYPE_WINDOW)
+G_DEFINE_TYPE (GsReposDialog, gs_repos_dialog, ADW_TYPE_WINDOW)
 
 static void reload_third_party_repos (GsReposDialog *dialog);
 
 typedef struct {
-	GsReposDialog	*dialog;
-	GsApp		*repo;
-	GWeakRef	 row_weakref;
-	GsPluginAction	 action;
+	GsReposDialog		     *dialog;
+	GsApp			     *repo;
+	GWeakRef		      row_weakref;
+	GsPluginManageRepositoryFlags operation;
 } InstallRemoveData;
 
 static void
@@ -59,35 +59,6 @@ install_remove_data_free (InstallRemoveData *data)
 
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(InstallRemoveData, install_remove_data_free);
 
-static gboolean
-key_press_event_cb (GtkWidget            *sender,
-                    GdkEvent             *event,
-                    HdyPreferencesWindow *self)
-{
-	guint keyval;
-	GdkModifierType state;
-	GdkKeymap *keymap;
-	GdkEventKey *key_event = (GdkEventKey *) event;
-
-	gdk_event_get_state (event, &state);
-
-	keymap = gdk_keymap_get_for_display (gtk_widget_get_display (sender));
-
-	gdk_keymap_translate_keyboard_state (keymap,
-					     key_event->hardware_keycode,
-					     state,
-					     key_event->group,
-					     &keyval, NULL, NULL, NULL);
-
-	if (keyval == GDK_KEY_Escape) {
-		gtk_window_close (GTK_WINDOW (self));
-
-		return GDK_EVENT_STOP;
-	}
-
-	return GDK_EVENT_PROPAGATE;
-}
-
 static void
 repo_enabled_cb (GObject *source,
                  GAsyncResult *res,
@@ -97,24 +68,30 @@ repo_enabled_cb (GObject *source,
 	g_autoptr(InstallRemoveData) install_remove_data = (InstallRemoveData *) user_data;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsRepoRow) row = NULL;
-	const gchar *action_str;
+	const gchar *operation_str;
+
+	operation_str = install_remove_data->operation == GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_INSTALL ? "install" :
+			install_remove_data->operation == GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_REMOVE ? "remove" :
+			install_remove_data->operation == GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_ENABLE ? "enable" :
+			install_remove_data->operation == GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_DISABLE ? "disable" : NULL;
+	g_assert (operation_str != NULL);
 
-	action_str = gs_plugin_action_to_string (install_remove_data->action);
 	row = g_weak_ref_get (&install_remove_data->row_weakref);
 	if (row)
 		gs_repo_row_unmark_busy (row);
 
 	if (!gs_plugin_loader_job_action_finish (plugin_loader, res, &error)) {
-		if (g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED)) {
-			g_debug ("repo %s cancelled", action_str);
+		if (g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED) ||
+		    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+			g_debug ("repo %s cancelled", operation_str);
 			return;
 		}
 
-		g_warning ("failed to %s repo: %s", action_str, error->message);
+		g_warning ("failed to %s repo: %s", operation_str, error->message);
 		return;
 	}
 
-	g_debug ("finished %s repo %s", action_str, gs_app_get_id (install_remove_data->repo));
+	g_debug ("finished %s repo %s", operation_str, gs_app_get_id (install_remove_data->repo));
 }
 
 static void
@@ -123,10 +100,8 @@ _enable_repo (InstallRemoveData *install_data)
 	GsReposDialog *dialog = install_data->dialog;
 	g_autoptr(GsPluginJob) plugin_job = NULL;
 	g_debug ("enabling repo %s", gs_app_get_id (install_data->repo));
-	plugin_job = gs_plugin_job_newv (install_data->action,
-					 "interactive", TRUE,
-	                                 "app", install_data->repo,
-	                                 NULL);
+	plugin_job = gs_plugin_job_manage_repository_new (install_data->repo,
+							  install_data->operation | GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_INTERACTIVE);
 	gs_plugin_loader_job_process_async (dialog->plugin_loader, plugin_job,
 	                                    dialog->cancellable,
 	                                    repo_enabled_cb,
@@ -141,7 +116,7 @@ enable_repo_response_cb (GtkDialog *confirm_dialog,
 	g_autoptr(InstallRemoveData) install_data = (InstallRemoveData *) user_data;
 
 	/* unmap the dialog */
-	gtk_widget_destroy (GTK_WIDGET (confirm_dialog));
+	gtk_window_destroy (GTK_WINDOW (confirm_dialog));
 
 	/* not agreed */
 	if (response != GTK_RESPONSE_OK) {
@@ -162,7 +137,7 @@ enable_repo (GsReposDialog *dialog,
 	g_autoptr(InstallRemoveData) install_data = NULL;
 
 	install_data = g_slice_new0 (InstallRemoveData);
-	install_data->action = GS_PLUGIN_ACTION_ENABLE_REPO;
+	install_data->operation = GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_ENABLE;
 	install_data->dialog = g_object_ref (dialog);
 	install_data->repo = g_object_ref (repo);
 	g_weak_ref_init (&install_data->row_weakref, row);
@@ -222,7 +197,7 @@ remove_repo_response_cb (GtkDialog *confirm_dialog,
 	g_autoptr(GsPluginJob) plugin_job = NULL;
 
 	/* unmap the dialog */
-	gtk_widget_destroy (GTK_WIDGET (confirm_dialog));
+	gtk_window_destroy (GTK_WINDOW (confirm_dialog));
 
 	/* not agreed */
 	if (response != GTK_RESPONSE_OK) {
@@ -233,10 +208,9 @@ remove_repo_response_cb (GtkDialog *confirm_dialog,
 	}
 
 	g_debug ("removing repo %s", gs_app_get_id (remove_data->repo));
-	plugin_job = gs_plugin_job_newv (remove_data->action,
-					 "interactive", TRUE,
-					 "app", remove_data->repo,
-					 NULL);
+	plugin_job = gs_plugin_job_manage_repository_new (remove_data->repo,
+							  remove_data->operation |
+							  GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_INTERACTIVE);
 	gs_plugin_loader_job_process_async (dialog->plugin_loader, plugin_job,
 					    dialog->cancellable,
 					    repo_enabled_cb,
@@ -247,7 +221,7 @@ static void
 remove_confirm_repo (GsReposDialog *dialog,
 		     GsRepoRow *row,
 		     GsApp *repo,
-		     GsPluginAction action)
+		     GsPluginManageRepositoryFlags operation)
 {
 	InstallRemoveData *remove_data;
 	GtkWidget *confirm_dialog;
@@ -256,13 +230,13 @@ remove_confirm_repo (GsReposDialog *dialog,
 	GtkStyleContext *context;
 
 	remove_data = g_slice_new0 (InstallRemoveData);
-	remove_data->action = action;
+	remove_data->operation = operation;
 	remove_data->dialog = g_object_ref (dialog);
 	remove_data->repo = g_object_ref (repo);
 	g_weak_ref_init (&remove_data->row_weakref, row);
 
 	/* TRANSLATORS: The '%s' is replaced with a repository name, like "Fedora Modular - x86_64" */
-	message = g_strdup_printf (_("Software that has been installed from “%s” will cease receive updates."),
+	message = g_strdup_printf (_("Software that has been installed from “%s” will cease to receive updates."),
 			gs_app_get_name (repo));
 
 	/* ask for confirmation */
@@ -271,11 +245,11 @@ remove_confirm_repo (GsReposDialog *dialog,
 	                                         GTK_MESSAGE_QUESTION,
 	                                         GTK_BUTTONS_CANCEL,
 	                                         "%s",
-						 action == GS_PLUGIN_ACTION_DISABLE_REPO ? _("Disable Repository?") : _("Remove Repository?"));
+						 operation == GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_DISABLE ? _("Disable Repository?") : _("Remove Repository?"));
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (confirm_dialog),
 						  "%s", message);
 
-	if (action == GS_PLUGIN_ACTION_DISABLE_REPO) {
+	if (operation == GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_DISABLE) {
 		/* TRANSLATORS: this is button text to disable a repo */
 		button = gtk_dialog_add_button (GTK_DIALOG (confirm_dialog), _("_Disable"), GTK_RESPONSE_OK);
 	} else {
@@ -310,7 +284,7 @@ repo_section_switch_clicked_cb (GsReposSection *section,
 		enable_repo (dialog, row, repo);
 		break;
 	case GS_APP_STATE_INSTALLED:
-		remove_confirm_repo (dialog, row, repo, GS_PLUGIN_ACTION_DISABLE_REPO);
+		remove_confirm_repo (dialog, row, repo, GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_DISABLE);
 		break;
 	default:
 		g_warning ("repo %s button clicked in unexpected state %s",
@@ -326,7 +300,7 @@ repo_section_remove_clicked_cb (GsReposSection *section,
 				GsReposDialog *dialog)
 {
 	GsApp *repo = gs_repo_row_get_repo (row);
-	remove_confirm_repo (dialog, row, repo, GS_PLUGIN_ACTION_REMOVE_REPO);
+	remove_confirm_repo (dialog, row, repo, GS_PLUGIN_MANAGE_REPOSITORY_FLAGS_REMOVE);
 }
 
 static void
@@ -367,10 +341,13 @@ static gboolean
 is_third_party_repo (GsReposDialog *dialog,
 		     GsApp *repo)
 {
+	g_autoptr(GsPlugin) plugin = gs_app_dup_management_plugin (repo);
+	const gchar *plugin_name = (plugin != NULL) ? gs_plugin_get_name (plugin) : NULL;
+
 	return gs_app_get_scope (repo) == AS_COMPONENT_SCOPE_SYSTEM &&
 	       gs_fedora_third_party_util_is_third_party_repo (dialog->third_party_repos,
 							       gs_app_get_id (repo),
-							       gs_app_get_management_plugin (repo));
+							       plugin_name);
 }
 
 static void
@@ -399,15 +376,18 @@ add_repo (GsReposDialog *dialog,
 		return;
 	}
 
-	origin_ui = gs_app_get_origin_ui (repo);
+	origin_ui = gs_app_dup_origin_ui (repo, TRUE);
 	if (!origin_ui)
 		origin_ui = gs_app_get_packaging_format (repo);
-	if (!origin_ui)
-		origin_ui = g_strdup (gs_app_get_management_plugin (repo));
+	if (!origin_ui) {
+		g_autoptr(GsPlugin) plugin = gs_app_dup_management_plugin (repo);
+		origin_ui = (plugin != NULL) ? g_strdup (gs_plugin_get_name (plugin)) : NULL;
+	}
+
 	section = g_hash_table_lookup (dialog->sections, origin_ui);
 	if (section == NULL) {
-		section = gs_repos_section_new (dialog->plugin_loader, FALSE);
-		hdy_preferences_group_set_title (HDY_PREFERENCES_GROUP (section),
+		section = gs_repos_section_new (FALSE);
+		adw_preferences_group_set_title (ADW_PREFERENCES_GROUP (section),
 						 origin_ui);
 		g_signal_connect_object (section, "remove-clicked",
 					 G_CALLBACK (repo_section_remove_clicked_cb), dialog, 0);
@@ -439,8 +419,8 @@ repos_dialog_compare_sections_cb (gconstpointer aa,
 	if (res != 0)
 		return res;
 
-	title_sort_key_a = gs_utils_sort_key (hdy_preferences_group_get_title (HDY_PREFERENCES_GROUP (section_a)));
-	title_sort_key_b = gs_utils_sort_key (hdy_preferences_group_get_title (HDY_PREFERENCES_GROUP (section_b)));
+	title_sort_key_a = gs_utils_sort_key (adw_preferences_group_get_title (ADW_PREFERENCES_GROUP (section_a)));
+	title_sort_key_b = gs_utils_sort_key (adw_preferences_group_get_title (ADW_PREFERENCES_GROUP (section_b)));
 
 	return g_strcmp0 (title_sort_key_a, title_sort_key_b);
 }
@@ -455,13 +435,14 @@ get_sources_cb (GsPluginLoader *plugin_loader,
 	g_autoptr(GsAppList) list = NULL;
 	g_autoptr(GSList) other_repos = NULL;
 	g_autoptr(GList) sections = NULL;
+	AdwPreferencesGroup *added_section;
+	GHashTableIter iter;
 
 	/* get the results */
 	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
 	if (list == NULL) {
-		if (g_error_matches (error,
-				     GS_PLUGIN_ERROR,
-				     GS_PLUGIN_ERROR_CANCELLED)) {
+		if (g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED) ||
+		    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
 			g_debug ("get sources cancelled");
 			return;
 		} else {
@@ -472,11 +453,15 @@ get_sources_cb (GsPluginLoader *plugin_loader,
 	}
 
 	/* remove previous */
-	g_hash_table_remove_all (dialog->sections);
-	gs_container_remove_all (GTK_CONTAINER (dialog->content_page));
+	g_hash_table_iter_init (&iter, dialog->sections);
+	while (g_hash_table_iter_next (&iter, NULL, (gpointer *)&added_section)) {
+		adw_preferences_page_remove (ADW_PREFERENCES_PAGE (dialog->content_page),
+					     added_section);
+		g_hash_table_iter_remove (&iter);
+	}
 
 	/* stop the spinner */
-	gs_stop_spinner (GTK_SPINNER (dialog->spinner));
+	gtk_spinner_stop (GTK_SPINNER (dialog->spinner));
 
 	/* no results */
 	if (gs_app_list_length (list) == 0) {
@@ -495,8 +480,8 @@ get_sources_cb (GsPluginLoader *plugin_loader,
 	sections = g_hash_table_get_values (dialog->sections);
 	sections = g_list_sort (sections, repos_dialog_compare_sections_cb);
 	for (GList *link = sections; link; link = g_list_next (link)) {
-		GtkWidget *section = link->data;
-		gtk_container_add (GTK_CONTAINER (dialog->content_page), section);
+		AdwPreferencesGroup *section = link->data;
+		adw_preferences_page_add (ADW_PREFERENCES_PAGE (dialog->content_page), section);
 	}
 
 	gtk_widget_set_visible (dialog->content_page, sections != NULL);
@@ -507,6 +492,7 @@ get_sources_cb (GsPluginLoader *plugin_loader,
 		GtkWidget *row;
 		g_autofree gchar *anchor = NULL;
 		g_autofree gchar *hint = NULL;
+		g_autofree gchar *section_id = NULL;
 
 		widget = gtk_switch_new ();
 		gtk_widget_set_valign (widget, GTK_ALIGN_CENTER);
@@ -515,15 +501,18 @@ get_sources_cb (GsPluginLoader *plugin_loader,
 					 G_CALLBACK (fedora_third_party_repos_switch_notify_cb), dialog, 0);
 		gtk_widget_show (widget);
 
-		row = hdy_action_row_new ();
-		hdy_preferences_row_set_title (HDY_PREFERENCES_ROW (row), _("Enable New Repositories"));
-		hdy_action_row_set_subtitle (HDY_ACTION_ROW (row), _("Turn on new repositories when they are added."));
-		hdy_action_row_set_activatable_widget (HDY_ACTION_ROW (row), widget);
-		gtk_container_add (GTK_CONTAINER (row), widget);
+		row = adw_action_row_new ();
+#if ADW_CHECK_VERSION(1,2,0)
+		adw_preferences_row_set_use_markup (ADW_PREFERENCES_ROW (row), FALSE);
+#endif
+		adw_preferences_row_set_title (ADW_PREFERENCES_ROW (row), _("Enable New Repositories"));
+		adw_action_row_set_subtitle (ADW_ACTION_ROW (row), _("Turn on new repositories when they are added."));
+		adw_action_row_set_activatable_widget (ADW_ACTION_ROW (row), widget);
+		adw_action_row_add_suffix (ADW_ACTION_ROW (row), widget);
 		gtk_widget_show (row);
 
 		anchor = g_strdup_printf ("<a href=\"%s\">%s</a>",
-	                        "https://fedoraproject.org/wiki/Workstation/Third_Party_Software_Repositories",
+	                        "https://docs.fedoraproject.org/en-US/workstation-working-group/third-party-repos/",
 	                        /* TRANSLATORS: this is the clickable
 	                         * link on the third party repositories info bar */
 	                        _("more information"));
@@ -534,22 +523,22 @@ get_sources_cb (GsPluginLoader *plugin_loader,
 				_("Additional repositories from selected third parties — %s."),
 				anchor);
 
-		widget = hdy_preferences_group_new ();
-		hdy_preferences_group_set_title (HDY_PREFERENCES_GROUP (widget),
+		widget = adw_preferences_group_new ();
+		adw_preferences_group_set_title (ADW_PREFERENCES_GROUP (widget),
 						 _("Fedora Third Party Repositories"));
-/* HdyPreferencesGroup:use-markup doesn't exist before 1.3.90, configurations
- * where GNOME 41 will be used and Libhandy 1.3.90 won't be available are
- * unlikely, so let's just ignore the description in such cases. */
-#if HDY_CHECK_VERSION(1, 3, 90)
-		hdy_preferences_group_set_description (HDY_PREFERENCES_GROUP (widget), hint);
-		hdy_preferences_group_set_use_markup (HDY_PREFERENCES_GROUP (widget), TRUE);
-#endif
+
+		adw_preferences_group_set_description (ADW_PREFERENCES_GROUP (widget), hint);
 
 		gtk_widget_show (widget);
-		gtk_container_add (GTK_CONTAINER (widget), row);
-		gtk_container_add (GTK_CONTAINER (dialog->content_page), widget);
+		adw_preferences_group_add (ADW_PREFERENCES_GROUP (widget), row);
+		adw_preferences_page_add (ADW_PREFERENCES_PAGE (dialog->content_page),
+					  ADW_PREFERENCES_GROUP (widget));
 
-		section = GS_REPOS_SECTION (gs_repos_section_new (dialog->plugin_loader, TRUE));
+		/* use something unique, not clashing with the other section names */
+		section_id = g_strdup_printf ("fedora-third-party::1::%p", widget);
+		g_hash_table_insert (dialog->sections, g_steal_pointer (&section_id), widget);
+
+		section = GS_REPOS_SECTION (gs_repos_section_new (TRUE));
 		gs_repos_section_set_sort_key (section, "900");
 		g_signal_connect_object (section, "switch-clicked",
 					 G_CALLBACK (repo_section_switch_clicked_cb), dialog, 0);
@@ -560,7 +549,12 @@ get_sources_cb (GsPluginLoader *plugin_loader,
 			gs_repos_section_add_repo (section, repo);
 		}
 
-		gtk_container_add (GTK_CONTAINER (dialog->content_page), GTK_WIDGET (section));
+		/* use something unique, not clashing with the other section names */
+		section_id = g_strdup_printf ("fedora-third-party::2::%p", section);
+		g_hash_table_insert (dialog->sections, g_steal_pointer (&section_id), section);
+
+		adw_preferences_page_add (ADW_PREFERENCES_PAGE (dialog->content_page),
+					  ADW_PREFERENCES_GROUP (section));
 	}
 }
 
@@ -733,7 +727,7 @@ gs_repos_dialog_init (GsReposDialog *dialog)
 	   %s gets replaced by the name of the actual distro, e.g. Fedora. */
 	label_empty_text = g_strdup_printf (_("These repositories supplement the default software provided by %s."),
 	                                    os_name);
-	hdy_status_page_set_description (HDY_STATUS_PAGE (dialog->status_empty), label_empty_text);
+	adw_status_page_set_description (ADW_STATUS_PAGE (dialog->status_empty), label_empty_text);
 }
 
 static void
@@ -751,7 +745,7 @@ gs_repos_dialog_class_init (GsReposDialogClass *klass)
 	gtk_widget_class_bind_template_child (widget_class, GsReposDialog, spinner);
 	gtk_widget_class_bind_template_child (widget_class, GsReposDialog, stack);
 
-	gtk_widget_class_bind_template_callback (widget_class, key_press_event_cb);
+	gtk_widget_class_add_binding_action (widget_class, GDK_KEY_Escape, 0, "window.close", NULL);
 }
 
 GtkWidget *
@@ -765,7 +759,7 @@ gs_repos_dialog_new (GtkWindow *parent, GsPluginLoader *plugin_loader)
 			       NULL);
 	set_plugin_loader (dialog, plugin_loader);
 	gtk_stack_set_visible_child_name (GTK_STACK (dialog->stack), "waiting");
-	gs_start_spinner (GTK_SPINNER (dialog->spinner));
+	gtk_spinner_start (GTK_SPINNER (dialog->spinner));
 	reload_third_party_repos (dialog);
 
 	return GTK_WIDGET (dialog);
