@@ -26,9 +26,7 @@ struct _GsSearchPage
 	GsPluginLoader		*plugin_loader;
 	GCancellable		*cancellable;
 	GCancellable		*search_cancellable;
-	GtkSizeGroup		*sizegroup_image;
 	GtkSizeGroup		*sizegroup_name;
-	GtkSizeGroup		*sizegroup_desc;
 	GtkSizeGroup		*sizegroup_button_label;
 	GtkSizeGroup		*sizegroup_button_image;
 	GsShell			*shell;
@@ -36,6 +34,7 @@ struct _GsSearchPage
 	gchar			*value;
 	guint			 waiting_id;
 	guint			 max_results;
+	guint			 stamp;
 	gboolean		 changed;
 
 	GtkWidget		*list_box_search;
@@ -98,30 +97,41 @@ gs_search_page_app_to_show_created_cb (GObject *source_object,
 	}
 }
 
+typedef struct {
+	GsSearchPage *self;
+	guint stamp;
+} GetSearchData;
+
 static void
 gs_search_page_get_search_cb (GObject *source_object,
                               GAsyncResult *res,
                               gpointer user_data)
 {
 	guint i;
+	g_autofree GetSearchData *search_data = user_data;
 	GsApp *app;
-	GsSearchPage *self = GS_SEARCH_PAGE (user_data);
+	GsSearchPage *self = search_data->self;
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
 	GtkWidget *app_row;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsAppList) list = NULL;
 
+	/* different stamps means another search had been started before this one finished */
+	if (search_data->stamp != self->stamp)
+		return;
+
 	/* don't do the delayed spinner */
 	gs_search_page_waiting_cancel (self);
 
 	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
 	if (list == NULL) {
-		if (g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED)) {
+		if (g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED) ||
+		    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
 			g_debug ("search cancelled");
 			return;
 		}
 		g_warning ("failed to get search apps: %s", error->message);
-		gs_stop_spinner (GTK_SPINNER (self->spinner_search));
+		gtk_spinner_stop (GTK_SPINNER (self->spinner_search));
 		if (self->value && self->value[0])
 			gtk_stack_set_visible_child_name (GTK_STACK (self->stack_search), "no-results");
 		else
@@ -140,9 +150,9 @@ gs_search_page_get_search_cb (GObject *source_object,
 	}
 
 	/* remove old entries */
-	gs_container_remove_all (GTK_CONTAINER (self->list_box_search));
+	gs_widget_remove_all (self->list_box_search, (GsRemoveFunc) gtk_list_box_remove);
 
-	gs_stop_spinner (GTK_SPINNER (self->spinner_search));
+	gtk_spinner_stop (GTK_SPINNER (self->spinner_search));
 	gtk_stack_set_visible_child_name (GTK_STACK (self->stack_search), "results");
 	for (i = 0; i < gs_app_list_length (list); i++) {
 		app = gs_app_list_index (list, i);
@@ -151,11 +161,9 @@ gs_search_page_get_search_cb (GObject *source_object,
 		g_signal_connect (app_row, "button-clicked",
 				  G_CALLBACK (gs_search_page_app_row_clicked_cb),
 				  self);
-		gtk_container_add (GTK_CONTAINER (self->list_box_search), app_row);
+		gtk_list_box_append (GTK_LIST_BOX (self->list_box_search), app_row);
 		gs_app_row_set_size_groups (GS_APP_ROW (app_row),
-					    self->sizegroup_image,
 					    self->sizegroup_name,
-					    self->sizegroup_desc,
 					    self->sizegroup_button_label,
 					    self->sizegroup_button_image);
 		gtk_widget_show (app_row);
@@ -179,8 +187,8 @@ gs_search_page_get_search_cb (GObject *source_object,
 		gtk_widget_set_margin_start (w, 20);
 		gtk_widget_set_margin_end (w, 20);
 		context = gtk_widget_get_style_context (w);
-		gtk_style_context_add_class (context, GTK_STYLE_CLASS_DIM_LABEL);
-		gtk_container_add (GTK_CONTAINER (self->list_box_search), w);
+		gtk_style_context_add_class (context, "dim-label");
+		gtk_list_box_append (GTK_LIST_BOX (self->list_box_search), w);
 		gtk_widget_show (w);
 	} else {
 		/* reset to default */
@@ -210,7 +218,7 @@ gs_search_page_waiting_show_cb (gpointer user_data)
 
 	/* show spinner */
 	gtk_stack_set_visible_child_name (GTK_STACK (self->stack_search), "spinner");
-	gs_start_spinner (GTK_SPINNER (self->spinner_search));
+	gtk_spinner_start (GTK_SPINNER (self->spinner_search));
 	gs_search_page_waiting_cancel (self);
 	return FALSE;
 }
@@ -266,6 +274,9 @@ static void
 gs_search_page_load (GsSearchPage *self)
 {
 	g_autoptr(GsPluginJob) plugin_job = NULL;
+	g_autoptr(GsAppQuery) query = NULL;
+	const gchar *keywords[2] = { NULL, };
+	g_autofree GetSearchData *search_data = NULL;
 
 	self->changed = FALSE;
 
@@ -273,31 +284,38 @@ gs_search_page_load (GsSearchPage *self)
 	g_cancellable_cancel (self->search_cancellable);
 	g_clear_object (&self->search_cancellable);
 	self->search_cancellable = g_cancellable_new ();
+	self->stamp++;
 
 	/* search for apps */
 	gs_search_page_waiting_cancel (self);
 	self->waiting_id = g_timeout_add (250, gs_search_page_waiting_show_cb, self);
-	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_SEARCH,
-					 "search", self->value,
-					 "max-results", self->max_results,
-					 "timeout", 0, /* This is a user action, let it take as long as it needs to */
-					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_HISTORY |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEW_RATINGS |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_DESCRIPTION |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENSE |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_PERMISSIONS |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING,
-					 "dedupe-flags", GS_APP_LIST_FILTER_FLAG_PREFER_INSTALLED |
-							 GS_APP_LIST_FILTER_FLAG_KEY_ID_PROVIDES,
-					 NULL);
-	gs_plugin_job_set_sort_func (plugin_job, gs_search_page_sort_cb, self);
+
+	search_data = g_new0 (GetSearchData, 1);
+	search_data->self = self;
+	search_data->stamp = self->stamp;
+
+	keywords[0] = self->value;
+	query = gs_app_query_new ("keywords", keywords,
+				  "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON |
+						  GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION |
+						  GS_PLUGIN_REFINE_FLAGS_REQUIRE_HISTORY |
+						  GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION |
+						  GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEW_RATINGS |
+						  GS_PLUGIN_REFINE_FLAGS_REQUIRE_DESCRIPTION |
+						  GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENSE |
+						  GS_PLUGIN_REFINE_FLAGS_REQUIRE_PERMISSIONS |
+						  GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING,
+				  "dedupe-flags", GS_APP_LIST_FILTER_FLAG_PREFER_INSTALLED |
+						  GS_APP_LIST_FILTER_FLAG_KEY_ID_PROVIDES,
+				  "max-results", self->max_results,
+				  "sort-func", gs_search_page_sort_cb,
+				  "sort-user-data", self,
+				  NULL);
+	plugin_job = gs_plugin_job_list_apps_new (query, GS_PLUGIN_LIST_APPS_FLAGS_NONE);
 	gs_plugin_loader_job_process_async (self->plugin_loader, plugin_job,
 					    self->search_cancellable,
 					    gs_search_page_get_search_cb,
-					    self);
+					    g_steal_pointer (&search_data));
 }
 
 static void
@@ -476,9 +494,7 @@ gs_search_page_dispose (GObject *object)
 {
 	GsSearchPage *self = GS_SEARCH_PAGE (object);
 
-	g_clear_object (&self->sizegroup_image);
 	g_clear_object (&self->sizegroup_name);
-	g_clear_object (&self->sizegroup_desc);
 	g_clear_object (&self->sizegroup_button_label);
 	g_clear_object (&self->sizegroup_button_image);
 
@@ -534,9 +550,7 @@ gs_search_page_init (GsSearchPage *self)
 {
 	gtk_widget_init_template (GTK_WIDGET (self));
 
-	self->sizegroup_image = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_name = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	self->sizegroup_desc = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_button_label = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_button_image = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
